//////////////////////////////////////////////////////////////////////////////
// Program Name: upnpcdsmusicalbum.cpp
//
// Purpose - uPnp Content Directory Extension for Music Albums
//
// Created By  : Joe Bryant                     Created On : Jul. 29, 2011
// Modified By :                                Modified On:
//
//////////////////////////////////////////////////////////////////////////////

#include <climits>

#include <QFileInfo>

#include "upnpcdsmusicalbum.h"
#include "httprequest.h"
#include "mythcorecontext.h"


UPnpCDSRootInfo UPnpCDSMusicAlbum::g_RootNodes[] =
{
   
    {   "By Album",
        "album.album_id",
        "SELECT a.album_id as id, "
          "a.album_name as name, "
          "count( song.album_id ) as children "
            "FROM music_songs song join music_albums a on a.album_id = song.album_id "
            "%1 "
            "GROUP BY a.album_id "
            "ORDER BY a.album_name",
        "WHERE album.album_id=:KEY" },

};

int UPnpCDSMusicAlbum::g_nRootCount = sizeof( g_RootNodes ) / sizeof( UPnpCDSRootInfo );

/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////

UPnpCDSRootInfo *UPnpCDSMusicAlbum::GetRootInfo( int nIdx, QString sContainerId )
{
    if ((nIdx >=0 ) && ( nIdx < g_nRootCount ))
        return &(g_RootNodes[ nIdx ]);

    return NULL;
}

/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////

int UPnpCDSMusicAlbum::GetRootCount()
{
    return g_nRootCount;
}

/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////

QString UPnpCDSMusicAlbum::GetTableName( QString sColumn )
{
    return "music_albums album";
}

/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////

QString UPnpCDSMusicAlbum::GetItemListSQL( QString /* sColumn */ )
{
    return "select album_id as intid, artist_name as artist, album_name as album " \
           "from music_albums " \
           "join music_artists " \
           "on music_albums.artist_id = music_artists.artist_id";
}

/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////

void UPnpCDSMusicAlbum::BuildItemQuery( MSqlQuery &query, const QStringMap &mapParams )
{
    int     nId    = mapParams[ "Id" ].toInt();

    QString sSQL = QString( "%1 WHERE music_albums.album_id=:ID " )
                      .arg( GetItemListSQL() );

    query.prepare( sSQL );

    query.bindValue( ":ID", (int)nId );
}


/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////

void UPnpCDSMusicAlbum::AddItem( const UPnpCDSRequest    *pRequest, 
                            const QString           &sObjectId,
                            UPnpCDSExtensionResults *pResults,
                            bool                     bAddRef,
                            MSqlQuery               &query )
{
    QString sName;

    QString sId     = QString( "musicalbum" ) + query.value( 0 ).toString();
    QString sArtist = query.value( 1 ).toString();
    QString sAlbum  = query.value( 2 ).toString();

    CDSObject *pItem = CDSObject::CreateMusicAlbum( QString( sId ), sAlbum, QString( "1" ), NULL);
    
    pItem->SetPropValue( "artist", sArtist );

    pResults->Add( pItem );

}

// vim:ts=4:sw=4:ai:et:si:sts=4
